@@ -18,7 +18,7 @@
 #'
 #' @references \insertRef{woodStraightforwardIntermediateRank2013}{galamm}
 #'
-#' \insertRef{woodGeneralizedAdditiveModels2017a}{galamm}
+#' \insertRef{woodGeneralizedAdditiveModels2017}{galamm}
 #'
 #'
 gamm4.setup <- function(formula, pterms, mf) {
@@ -110,7 +110,7 @@ gamm4.setup <- function(formula, pterms, mf) {
 #' @references
 #' \insertRef{woodStraightforwardIntermediateRank2013}{galamm}
 #'
-#' \insertRef{woodGeneralizedAdditiveModels2017a}{galamm}
+#' \insertRef{woodGeneralizedAdditiveModels2017}{galamm}
 #'
 #' @srrstats {G1.4a} Internal function documented.
 #'
@@ -191,7 +191,12 @@ gamm4 <- function(fixed, random = NULL, data) {
   }
 
   lme4.formula <- stats::as.formula(lme4.formula)
-  b <- lme4::lFormula(lme4.formula, data = mf, REML = FALSE)
+  b <- lme4::lFormula(
+    formula = lme4.formula,
+    data = mf,
+    REML = FALSE,
+    control = lme4::lmerControl(check.rankX = "stop.deficient")
+    )
 
   tn <- names(b$reTrms$cnms)
   ind <- seq_along(tn)
